# sails.tcl  -*- TCL -*-
#---------------------------------------------------------------------------
#This file is written in TCL lenguage 
#For more information about TCL look at: http://www.sunlabs.com/research/tcl/
#
#At least two procs must be in this file:
#
#    InitGIDProject dir - Will be called whenever a project is begun to be used.
#           where dir is the project's directory
#    EndGIDProject - Will be called whenever a project ends to be used.
#
#For more information about GID internals, check the program scripts.
#---------------------------------------------------------------------------


proc MyBitmaps { dir { type "DEFAULT INSIDELEFT"} } {
    global MyBitmapsNames MyBitmapsCommands MyBitmapsHelp Caltep2000

    set MyBitmapsNames(0) "internas.gif constraints.gif loads.gif section.gif \
	    general.gif mesh.gif calc.gif logo.gif"
    set MyBitmapsCommands(0) [list [list -np- GidOpenConditions Fixed_Temperature] \
	    [list -np- GidOpenConditions External_Temperature] \
	    [list -np- GidOpenConditions Loads] \
	    [list -np- GidOpenMaterials] \
	    [list -np- GidOpenProblemData] \
	    "Meshing generate" \
	    "Utilities Calculate" \
             ]
    set MyBitmapsHelp(0) { "Assign Fixed Temperatures" "Assign External Temperatures" \
	    "Assign loads" "Assign Properties" \
	    "Problem data" "Generate mesh" "Calculate" "Caltep 2000 by CIMNE"}
    
    # prefix values:
    #          Pre        Only active in the preprocessor
    #          Post       Only active in the postprocessor
    #          PrePost    Active Always

    set prefix Pre

    set Caltep2000(toolbarwin) [CreateOtherBitmaps MyBar "My toolbar" \
	    MyBitmapsNames MyBitmapsCommands \
	    MyBitmapsHelp $dir "MyBitmaps [list $dir]" $type $prefix]
    AddNewToolbar "Caltep2000 bar" ${prefix}MyBarWindowGeom \
	    "MyBitmaps [list $dir]"
}

proc EndMyBitmaps {} {
    global Caltep2000
    
    ReleaseToolbar "Caltep2000 bar"
    rename MyBitmaps ""
    
    catch { destroy $Caltep2000(toolbarwin) }
}

proc InitGIDProject { dir } {
    global MenuNames MenuEntries MenuCommands MenuAcceler
    global MenuNamesP MenuEntriesP MenuCommandsP MenuAccelerP

    set num [lsearch $MenuNamesP [_ "View results"]]
    if { $num == -1 } {
	WarnWin "Caltep2000 is not compatible with this GiD version"
	return
    }

    Splash $dir

#    foreach i [array names MenuEntriesP $num,*] "unset MenuEntriesP($i)"
#    foreach i [array names MenuCommandsP $num,*] "unset MenuCommandsP($i)"
#    set MenuEntriesP($num) ""
#    set MenuCommandsP($num) "-np- CreatePostProcessMenu %W"

    set ipos [lsearch $MenuNames [_ "Help"]]
    if { $ipos != -1 } {
	set MenuEntries($ipos) [linsert $MenuEntries($ipos) 0 "Help on Caltep2000"]
	set MenuCommands($ipos) [linsert $MenuCommands($ipos) 0 \
		[list -np- HelpOnCaltep2000 $dir]]
	set MenuAcceler($ipos) [linsert $MenuAcceler($ipos) 0 ""]
	CreateTopMenus
    }
    set ipos [lsearch $MenuNamesP Help]
    if { $ipos != -1 } {
	set MenuEntriesP($ipos) [linsert $MenuEntriesP($ipos) 0 "Help on Caltep2000"]
	set MenuCommandsP($ipos) [linsert $MenuCommandsP($ipos) 0 \
		[list -np- HelpOnCaltep2000 $dir]]
	set MenuAccelerP($ipos) [linsert $MenuAccelerP($ipos) 0 ""]
    }

    MyBitmaps $dir

    GidChangeDataLabel "Data units" ""
    GidChangeDataLabel "Interval" ""
    GidChangeDataLabel "Conditions" ""
    GidChangeDataLabel "Local Axes" ""
    
    GidAddUserDataOptions "Fixed Temperature" "GidOpenConditions Fixed_Temperature" 2
    GidAddUserDataOptions "External Temperature" "GidOpenConditions External_Temperature" 3
    GidAddUserDataOptions Loads "GidOpenConditions Loads" 4
    GidAddUserDataOptions "---" "" 7
    
}

proc EndGIDProject {} {
    EndMyBitmaps
}

proc HelpOnCaltep2000 { dir } {

    WarnWin [join [list "To obtain help for Caltep 2000, check the lates news in " \
                        "www.cimne.upc.es "]]

}

#  Rutina Modificada para Caltep 2000
#  8 / 11 / 2000
#  Esta rutnia despliega el logo del programa y la version

proc Splash { dir } {
    global GIDDEFAULT

    set VersionNumber "2.1"

    if { [.gid.central.s disable windows] } { return }

    if { [ winfo exist .splash]} {
	destroy .splash
	update
    }

    toplevel .splash
        
    set im [image create photo -file [ file join $dir caltep2000-open.gif]]
    set x [expr [winfo screenwidth .splash]/2-[image width $im]/2]
    set y [expr [winfo screenheight .splash]/2-[image height $im]/2]

    wm geom .splash +$x+$y
    wm transient .splash .gid
    wm overrideredirect .splash 1
    pack [label .splash.l -image $im -relief ridge -bd 2]
    
    label .splash.lv -text $VersionNumber -font "times 12"
    place .splash.lv -x 550 -y 130
    bind .splash <1> "destroy .splash"
    bind .splash <KeyPress> "destroy .splash"
    raise .splash .gid
    grab .splash
    focus .splash
    update

    after 7000 "if { [ winfo exist .splash] } { 
	destroy .splash
    }"
}

#proc SetVarsForBeams {} {
#    global MenuEntriesP MenuCommandsP MenuNamesP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set MenuEntriesP($num) "{Beam Diagrams} Deformed Reactions {M Reactions} \
#	    {Local axes} {No results}"
#    set MenuCommandsP($num) { {} {-np- DisplayDeformed} \
#	    {Results DisplayVectors Reactions |Reactions|} \
#	    {Results DisplayVectors M_Reactions |M_Reactions|} \
#	    {Results DisplayVectors Local_Axes_Beam All} \
#	    {-np- StopResults} }
#    
#    set res "{Axial force} Y'_Shear Z'_Shear Torsor Y'_Momentus Z'_Momentus"
#    set resp "X'_Shear Y'_Shear Z'_Shear X'_Momentus Y'_Momentus Z'_Momentus"
#
#    set MenuEntriesP($num,0) "$res"
#    set MenuCommandsP($num,0) ""
#    foreach i $resp {
#	lappend MenuCommandsP($num,0) "-np- DisplayVectorLineDiagram $i"
#    }
#}

#proc AddVarsForBeams {} {
#    global MenuNamesP MenuEntriesP MenuCommandsP
#    
#    set num [lsearch $MenuNamesP "View results"]
#
#    append MenuEntriesP($num) " --- {Beam Diagrams} {Beam Local axes}"
#    append MenuCommandsP($num) { {} {} \
#	    {Results DisplayVectors Local_Axes_Beam All} }
#    
#    set res "{Axial force} Y'_Shear Z'_Shear Torsor Y'_Momentus Z'_Momentus"
#    set resp "X'_Shear Y'_Shear Z'_Shear X'_Momentus Y'_Momentus Z'_Momentus"
#
#    set ipos [lsearch $MenuEntriesP($num) {Beam Diagrams}]
#    set MenuEntriesP($num,$ipos) "$res"
#    set MenuCommandsP($num,$ipos) ""
#    foreach i $resp {
#	lappend MenuCommandsP($num,$ipos) "-np- DisplayVectorLineDiagram $i"
#    }
#}

#proc SetVarsForShellsXY {} {
#    global MenuNamesP MenuEntriesP MenuCommandsP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set MenuEntriesP($num) "Displacements {Axial force} Momentus Shear --- \
#	    Deformed Reactions {M Reactions} \
#	    {Local axes} {No results}"
#    set MenuCommandsP($num) { {} {} {} {} {} {-np- DisplayDeformed} \
#	    {Results DisplayVectors Reactions |Reactions|} \
#	    {Results DisplayVectors M_Reactions |M_Reactions|} \
#	    {Results DisplayVectors Local_Axes All} \
#	    {-np- StopResults} }
   
#    set MenuEntriesP($num,0) { X Y Z |Displacements|}
#    set MenuEntriesP($num,1) { Nx' Ny' Nxy' }
#    set MenuEntriesP($num,2) { Mx' My' Mxy' }
#    set MenuEntriesP($num,3) { Qx' Qy' }
#
#    for {set i 0} {$i<4} {incr i} {
#	set MenuCommandsP($num,$i) ""
#	regsub -all { } [lindex $MenuEntriesP($num) $i] {_} res
#	foreach j $MenuEntriesP($num,$i) {
#	    lappend MenuCommandsP($num,$i) "-np- DisplayContourFill $res $j"
#	}
#    }
#}


#proc SetVarsForSolids {} {
#    global MenuNamesP MenuEntriesP MenuCommandsP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set MenuEntriesP($num) "Displacements Strengths {Von Misses} --- \
#	    Deformed Reactions --- {No results}"
#    set MenuCommandsP($num) { {} {} {-np- DisplayContourFill Von_Misses Von_Misses} {} \
#	    {-np- DisplayDeformed}  \
#	    {Results DisplayVectors Reactions |Reactions|} \
#	    {} {-np- StopResults} }
#   
#    set MenuEntriesP($num,0) { X Y Z |Displacements|}
#    set MenuEntriesP($num,1) {Sx Sy Sz Txy Txz Tyz Si-Strengths Sii-Strengths Siii-Strengths}
#
#    for {set i 0} {$i<2} {incr i} {
#	set MenuCommandsP($num,$i) ""
#	regsub -all { } [lindex $MenuEntriesP($num) $i] {_} res
#	foreach j $MenuEntriesP($num,$i) {
#	    lappend MenuCommandsP($num,$i) "-np- DisplayContourFill $res $j"
#	}
#    }
#}

#proc SetVarsForShellsMain {} {
#    global MenuNamesP MenuEntriesP MenuCommandsP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set MenuEntriesP($num) "Displacements {Main Ax. Force} {Main Momentus} \
#	    {Shear in Main} --- Deformed Reactions {M Reactions} \
#	    {Local axes Axial} {Local axes Momentus} {No results}"
#    set MenuCommandsP($num) { {} {} {} {} {} {-np- DisplayDeformed} \
#	    {Results DisplayVectors Reactions |Reactions|} \
#	    {Results DisplayVectors M_Reactions |M_Reactions|} \
#	    {Results DisplayVectors L_Axes_Axial All} \
#	    {Results DisplayVectors L_Axes_Momentus All } \
#	    {-np- StopResults} }
#   
#    set MenuEntriesP($num,0) { X Y Z |Displacements|}
#    set MenuEntriesP($num,1) { N11 N22 }
#    set MenuEntriesP($num,2) { M11 M22 }
#    set MenuEntriesP($num,3) { Qm1 Qm2 }
#
#    for {set i 0} {$i<4} {incr i} {
#	set MenuCommandsP($num,$i) ""
#	regsub -all { } [lindex $MenuEntriesP($num) $i] {_} res
#	foreach j $MenuEntriesP($num,$i) {
#	    lappend MenuCommandsP($num,$i) "-np- DisplayContourFill $res $j"
#	}
#    }
#}

#proc SetVarsForShellsBoth {} {
#    global MenuNamesP MenuEntriesP MenuCommandsP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set MenuEntriesP($num) "Displacements {Axial force} {Main Ax. Force} Momentus \
#	    {Main Momentus} Shear {Shear in Main} --- \
#	    Deformed Reactions {M Reactions} \
#	    {Local axes} {Local axes Axial} {Local axes Momentus} {No results}"
#    set MenuCommandsP($num) { {} {} {} {} {} {} {} {} {-np- DisplayDeformed} \
#	    {Results DisplayVectors Reactions |Reactions|} \
#	    {Results DisplayVectors M_Reactions |M_Reactions|} \
#	    {Results DisplayVectors Local_Axes All } \
#	    {Results DisplayVectors L_Axes_Axial All} \
#	    {Results DisplayVectors L_Axes_Momentus All } \
#	    {-np- StopResults} }
#   
#    set MenuEntriesP($num,0) { X Y Z |Displacements|}
#    set MenuEntriesP($num,1) { Nx' Ny' Nxy' }
#    set MenuEntriesP($num,2) { N11 N22 }
#    set MenuEntriesP($num,3) { Mx' My' Mxy' }
#    set MenuEntriesP($num,4) { M11 M22 }
#    set MenuEntriesP($num,5) { Qx' Qy' }
#    set MenuEntriesP($num,6) { Qm1 Qm2 }
#
#    for {set i 0} {$i<7} {incr i} {
#	set MenuCommandsP($num,$i) ""
#	regsub -all { } [lindex $MenuEntriesP($num) $i] {_} res
#	foreach j $MenuEntriesP($num,$i) {
#	    lappend MenuCommandsP($num,$i) "-np- DisplayContourFill $res $j"
#	}
#    }
#}

#proc SetVarsForNoneWin {} {
#    WarnWin "There are no Results"
#}

#proc SetVarsForNone {} {
#    global MenuNamesP MenuEntriesP MenuCommandsP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set MenuEntriesP($num) "{No Results}"
#    set MenuCommandsP($num) { {-np- SetVarsForNoneWin} }
#
#}

#proc CreatePostProcessMenu { w } {
#    global BarresPriv MenuNamesP
#
#    set num [lsearch $MenuNamesP "View results"]
#
#    set infoProj [lindex [.gid.central.s info Project] 4]
#    if { $infoProj != "POSTUSE" && $infoProj != "GRAFUSE" } { return }
#
#
#    set alla [.central.s info postprocess get all_analisis]
#    if { [lsearch $alla Estatic] != -1 } {
#	set restype [.central.s info postprocess get results_list Contour_Fill \
#		Estatic 1]
#    } else { set restype "" }
#    
#    if { [lsearch $restype Strengths] != -1 } {
#	set type solid
#    } elseif { [lsearch $restype Axial_Force] != -1 && \
#	    [lsearch $restype Main_Ax._Force] != -1 } {
#	set type both
#    } elseif { [lsearch $restype Axial_Force] != -1 } {
#	set type xy
#    } elseif { [lsearch $restype Main_Ax._Force] != -1 } {
#	set type main
#    } elseif { [lsearch $restype X'_Momentus] != -1 } {
#	set type beams
#    } else { set type none }
#
#    if { $type != "beams" && [lsearch $restype X'_Momentus] != -1 } {
#	set type2 beams
#    } else { set type2  "" }
#
#    if { ![info exists BarresPriv(problemtype)] || \
#	    $BarresPriv(problemtype) != $type || \
#	    $BarresPriv(problemtype2) != $type2 || [$w index end] == "none" } {
#	switch $type {
#	    solid SetVarsForSolids
#	    beams SetVarsForBeams
#	    both SetVarsForShellsBoth
#	    xy SetVarsForShellsXY
#	    main SetVarsForShellsMain
#	    none SetVarsForNone
#	}
#	if { $type2 == "beams" } {
#	    AddVarsForBeams
#	}
#
#	$w del 0 end
#	CreateCascadedMenu $w MenuEntriesP MenuCommandsP MenuAcceler $num
#    }
#    set BarresPriv(problemtype) $type
#    set BarresPriv(problemtype2) $type2
#}


#proc StopResults {} {
#    .central.s process escape escape escape escape Results Geometry \
#	    NoResults escape
#    .central.s process escape escape escape escape Results Geometry HideTheShow \
#	    escape
#}

#proc DisplayScalarLineDiagram { args } {
#    
#    .central.s process escape escape escape escape Results LineDiagram \
#	    Options ShowElevations NodesOnly LineDiagram ScalarDiagram $args
#}

#proc DisplayVectorLineDiagram { args } {
#    .central.s process escape escape escape escape Results LineDiagram \
#	    Options ShowElevations NodesOnly LineDiagram VectorDiagram $args
#}

#proc DisplayDeformedSD { args } {
#
#    .central.s process escape escape escape escape Results Geometry ShowDeformed \
#	    Estatic 1 $args escape escape
#}

#proc DisplayContourFill { args } {
#
#    .central.s process escape escape escape escape Results ContourFill $args \
#	    escape
#}

#proc DisplayGraphs { args } {
#
#    .central.s process escape escape escape escape Results Graphs BorderGraph \
#	    LineVariation $args
#}

#proc DisplayDeformed {} {
#
#    set alla [.central.s info postprocess get all_analisis]
#    if { [lsearch $alla Estatic] != -1 } {
#	set restype [.central.s info postprocess get results_list Contour_Fill \
#		Estatic 1]
#    } else { set restype "" }
#
#    if { [lsearch $restype Displacements] != -1 } {
#	DisplayDeformedSD Displacements
#    } else {
#	DisplayVectorLineDiagram BDisplacements
#    }
#}
